@@ -17,16 +17,16 @@ class Environment(BaseEnvironment):
     DispatchingJinjaLoader, and enables async Jinja by default.
     """
 
-    def __init__(self, app: 'Quart', **options: Any) -> None:
+    def __init__(self, app: "Quart", **options: Any) -> None:
         """Create a Quart specific Jinja2 Environment.
 
         Arguments:
             app: The Quart app to bind to.
             options: The standard Jinja2 Environment options.
         """
-        if 'loader' not in options:
-            options['loader'] = app.create_global_jinja_loader()
-        options['enable_async'] = True
+        if "loader" not in options:
+            options["loader"] = app.create_global_jinja_loader()
+        options["enable_async"] = True
         super().__init__(**options)
 
 
@@ -37,11 +37,11 @@ class DispatchingJinjaLoader(BaseLoader):
     and blueprints.
     """
 
-    def __init__(self, app: 'Quart') -> None:
+    def __init__(self, app: "Quart") -> None:
         self.app = app
 
     def get_source(
-            self, environment: Environment, template: str,
+        self, environment: Environment, template: str
     ) -> Tuple[str, Optional[str], Callable]:
         """Returns the template source from the environment.
 
@@ -112,8 +112,8 @@ async def _render(template: Template, context: dict) -> str:
 async def _default_template_context_processor() -> Dict[str, Any]:
     context = {}
     if has_app_context():
-        context['g'] = _app_ctx_stack.top.g
+        context["g"] = _app_ctx_stack.top.g
     if has_request_context():
-        context['request'] = _request_ctx_stack.top.request
-        context['session'] = _request_ctx_stack.top.session
+        context["request"] = _request_ctx_stack.top.request
+        context["session"] = _request_ctx_stack.top.session
     return context
