@@ -233,7 +233,7 @@ class Request(BaseRequestWebsocket, JSONMixin):
         elif content_type == "multipart/form-data":
             field_storage = FieldStorage(
                 io.BytesIO(raw_data),
-                headers=self.headers,  # type: ignore
+                headers={**self.headers},  # type: ignore
                 environ={"REQUEST_METHOD": "POST"},
                 limit=len(raw_data),
             )
